==> haskell-test-framework-smallcheck-0.2-321-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-test-framework-smallcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 test-framework-smallcheck
version:              0.2
visibility:           public
id:                   test-framework-smallcheck-0.2-53kcfLXnlG4sxG3KZg5LI
key:                  test-framework-smallcheck-0.2-53kcfLXnlG4sxG3KZg5LI
license:              BSD-3-Clause
maintainer:           Roman Cheplyaka <roma@ro-che.info>
author:               Roman Cheplyaka <roma@ro-che.info>
homepage:             https://github.com/feuerbach/smallcheck
synopsis:             Support for SmallCheck tests in test-framework
description:          Support for SmallCheck tests in test-framework
category:             Testing
abi:                  890cc12f8204fe95d4dcdb61ac211809
exposed:              True
exposed-modules:      Test.Framework.Providers.SmallCheck
import-dirs:          /usr/lib/ghc-9.4.8/site-local/test-framework-smallcheck-0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/test-framework-smallcheck-0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/test-framework-smallcheck-0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-test-framework-smallcheck
hs-libraries:         HStest-framework-smallcheck-0.2-53kcfLXnlG4sxG3KZg5LI
depends:
    base-4.17.2.1 smallcheck-1.2.1.1-FUla9WD5pMdAp5uIw7MiIm
    test-framework-0.8.2.2-JXKyeuMwMoaN1JH08Hy5c transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-test-framework-smallcheck/html/test-framework-smallcheck.haddock

haddock-html:         /usr/share/doc/haskell-test-framework-smallcheck/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-test-framework-smallcheck-0.2-322-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-test-framework-smallcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 test-framework-smallcheck
version:              0.2
visibility:           public
id:                   test-framework-smallcheck-0.2-LB5AbjBNmov9yWb4iwW67j
key:                  test-framework-smallcheck-0.2-LB5AbjBNmov9yWb4iwW67j
license:              BSD-3-Clause
maintainer:           Roman Cheplyaka <roma@ro-che.info>
author:               Roman Cheplyaka <roma@ro-che.info>
homepage:             https://github.com/feuerbach/smallcheck
synopsis:             Support for SmallCheck tests in test-framework
description:          Support for SmallCheck tests in test-framework
category:             Testing
abi:                  d1f3cf325a5c325ecddb1dde476adf5f
exposed:              True
exposed-modules:      Test.Framework.Providers.SmallCheck
import-dirs:          /usr/lib/ghc-9.4.8/site-local/test-framework-smallcheck-0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/test-framework-smallcheck-0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/test-framework-smallcheck-0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-test-framework-smallcheck
hs-libraries:         HStest-framework-smallcheck-0.2-LB5AbjBNmov9yWb4iwW67j
depends:
    base-4.17.2.1 smallcheck-1.2.1.1-A6MRwDBz8x45mEbSL1eKgr
    test-framework-0.8.2.2-GvpddZW7eUaFClLNjtd6h transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-test-framework-smallcheck/html/test-framework-smallcheck.haddock

haddock-html:         /usr/share/doc/haskell-test-framework-smallcheck/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
